==> mx-bootrepair_18.12.tar.xz: mx-bootrepair-18.12/translations/mx-bootrepair_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as root.</source>
        <translation>Diese Anwendung muss als Benutzer &quot;root&quot; ausgeführt werden.</translation>
    </message>
</context>
<context>
    <name>mxbootrepair</name>
    <message>
        <location filename="../mxbootrepair.ui" line="20"/>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>MX Boot Repair</source>
        <translation>MX Boot-Reparatur</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
        <translation>MX Boot-Reparatur ist ein Dienstprogramm, das benutzt werden kann, um den GRUB-Bootloader in dem MBR (Master Boot Record) oder Bootsektor zu restaurieren. Es bietet die Möglichkeit, sowohl die GRUB-Konfigurationsdatei zu rekonstruieren als auch den MBR oder PBR zu sichern und restaurieren.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>Was wollen Sie tun?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>MBR oder PBR sichern (nur Legacy-Boot)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="86"/>
        <source>Reinstall GRUB bootloader</source>
        <translation>Bootloader GRUB neu installieren</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Konfigurationsdatei von GRUB reparieren</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>MBR oder PBR aus Backup wieder herstellen (nur Legacy-Boot)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="123"/>
        <location filename="../mxbootrepair.cpp" line="378"/>
        <source>Select Boot Method</source>
        <translation>Boot-Methode auswählen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="141"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="144"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="147"/>
        <location filename="../mxbootrepair.ui" line="418"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="169"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Root (Bootsektor einer Partition)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="172"/>
        <location filename="../mxbootrepair.cpp" line="380"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="223"/>
        <location filename="../mxbootrepair.cpp" line="379"/>
        <source>Install on:</source>
        <translation>Installiere auf:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="242"/>
        <source>Location:</source>
        <translation>Einsatzort:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="264"/>
        <source>Select /boot location:</source>
        <translation>Boot-Einsatzort auswählen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="277"/>
        <source>EFI System Partition</source>
        <translation>EFI-Systempartition</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="280"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="407"/>
        <source>About this application</source>
        <translation>Über diese Anwendung</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="410"/>
        <source>About...</source>
        <translation>Impressum</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="460"/>
        <source>Display help </source>
        <translation>Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="463"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="471"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="512"/>
        <source>Cancel any changes then quit</source>
        <translation>Änderungen verwerfen und abbrechen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="515"/>
        <location filename="../mxbootrepair.cpp" line="451"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="523"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="542"/>
        <source>Apply any changes</source>
        <translation>Alle Änderungen akzeptieren</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="545"/>
        <location filename="../mxbootrepair.cpp" line="78"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="96"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>GRUB wird auf Gerät %1 installiert.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="111"/>
        <location filename="../mxbootrepair.cpp" line="134"/>
        <location filename="../mxbootrepair.cpp" line="164"/>
        <location filename="../mxbootrepair.cpp" line="266"/>
        <location filename="../mxbootrepair.cpp" line="300"/>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source>Could not mount </source>
        <translation>Kein Einbinden möglich von</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source> on /boot/efi</source>
        <translation>auf /boot/efi</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="135"/>
        <location filename="../mxbootrepair.cpp" line="165"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Die chroot-Umgebung konnte nicht eingerichtet werden.
Bitte prüfen Sie nochmals den ausgewählten Einsatzort.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="152"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>Die Konfigurationsdatei (grub.conf) von GRUB wird erneuert.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="186"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Der MBR oder PBR von Gerät %1 wird gesichert.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="241"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>You are going to write the content of </source>
        <translation>Sie werden den Inhalt der Datei schreiben</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source> to </source>
        <translation>in diese Datei</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>

Are you sure?</source>
        <translation>

Sind Sie sicher?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="247"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>MBR/PBR wird aus der Sicherung wiederhergestellt auf Gerät %1.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="267"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Konnte keine EFI-Systempartition (ESP) auf irgendeinem Laufwerk finden. Bitte erstellen Sie eine ESP und versuchen Sie es erneut.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="294"/>
        <source>Success</source>
        <translation>Erfolg</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="295"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Prozess erfolgreich beendet. &lt;p&gt;&lt;b&gt;Wollen Sie MX Boot-Reparatur schliessen?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="301"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Prozess beendet. Es sind Fehler aufgetreten.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="303"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="387"/>
        <source>Select GRUB location</source>
        <translation>Auswahl des Ziels für GRUB</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="398"/>
        <source>Select Item to Back Up</source>
        <translation>Eintrag zur Sicherung auswählen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="405"/>
        <source>Select Item to Restore</source>
        <translation>Eintrag zum Wiederherstellen auswählen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="416"/>
        <source>Select backup file name</source>
        <translation>Wählen Sie den Backup-Dateinamen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>No file was selected.</source>
        <translation>Es wurde keine Datei ausgewählt.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="423"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Backup-Datei MBR oder PBR auswählen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="444"/>
        <source>About MX Boot Repair</source>
        <translation>Über MX Boot-Reparatur</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>Version: </source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="447"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Einfaches Boot-Reparatur Program für MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="448"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="449"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="450"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="472"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
</context>
</TS>

==> mx-bootrepair_19.1.tar.xz: mx-bootrepair-19.1/translations/mx-bootrepair_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as root.</source>
        <translation>Diese Anwendung muss als Benutzer &quot;root&quot; ausgeführt werden.</translation>
    </message>
</context>
<context>
    <name>mxbootrepair</name>
    <message>
        <location filename="../mxbootrepair.ui" line="20"/>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>MX Boot Repair</source>
        <translation>MX Boot-Reparatur</translation>
    </message>
    <message>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
        <translation type="vanished">MX Boot-Reparatur ist ein Dienstprogramm, das benutzt werden kann, um den GRUB-Bootloader in dem MBR (Master Boot Record) oder Bootsektor zu restaurieren. Es bietet die Möglichkeit, sowohl die GRUB-Konfigurationsdatei zu rekonstruieren als auch den MBR oder PBR zu sichern und restaurieren.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>Was wollen Sie tun?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>MBR oder PBR sichern (nur Legacy-Boot)</translation>
    </message>
    <message>
        <source>Reinstall GRUB bootloader</source>
        <translation type="vanished">Bootloader GRUB neu installieren</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Konfigurationsdatei von GRUB reparieren</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>MBR oder PBR aus Backup wieder herstellen (nur Legacy-Boot)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="123"/>
        <location filename="../mxbootrepair.cpp" line="378"/>
        <source>Select Boot Method</source>
        <translation>Boot-Methode auswählen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="141"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="144"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="147"/>
        <location filename="../mxbootrepair.ui" line="417"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="169"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Root (Bootsektor einer Partition)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="172"/>
        <location filename="../mxbootrepair.cpp" line="380"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="223"/>
        <location filename="../mxbootrepair.cpp" line="379"/>
        <source>Install on:</source>
        <translation>Installiere auf:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="242"/>
        <source>Location:</source>
        <translation>Einsatzort:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="264"/>
        <source>Select /boot location:</source>
        <translation>Boot-Einsatzort auswählen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="277"/>
        <source>EFI System Partition</source>
        <translation>EFI-Systempartition</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="280"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="407"/>
        <source>About this application</source>
        <translation>Über diese Anwendung</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="410"/>
        <source>About...</source>
        <translation>Impressum</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="459"/>
        <source>Display help </source>
        <translation>Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="462"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="469"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="510"/>
        <source>Cancel any changes then quit</source>
        <translation>Änderungen verwerfen und abbrechen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="513"/>
        <location filename="../mxbootrepair.cpp" line="451"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="520"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="539"/>
        <source>Apply any changes</source>
        <translation>Alle Änderungen akzeptieren</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="542"/>
        <location filename="../mxbootrepair.cpp" line="78"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="96"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>GRUB wird auf Gerät %1 installiert.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="111"/>
        <location filename="../mxbootrepair.cpp" line="134"/>
        <location filename="../mxbootrepair.cpp" line="164"/>
        <location filename="../mxbootrepair.cpp" line="266"/>
        <location filename="../mxbootrepair.cpp" line="300"/>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source>Could not mount </source>
        <translation>Kein Einbinden möglich von</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source> on /boot/efi</source>
        <translation>auf /boot/efi</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="135"/>
        <location filename="../mxbootrepair.cpp" line="165"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Die chroot-Umgebung konnte nicht eingerichtet werden.
Bitte prüfen Sie nochmals den ausgewählten Einsatzort.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="152"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>Die Konfigurationsdatei (grub.conf) von GRUB wird erneuert.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="186"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Der MBR oder PBR von Gerät %1 wird gesichert.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="241"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>You are going to write the content of </source>
        <translation>Sie werden den Inhalt der Datei schreiben</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source> to </source>
        <translation>in diese Datei</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>

Are you sure?</source>
        <translation>

Sind Sie sicher?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="247"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>MBR/PBR wird aus der Sicherung wiederhergestellt auf Gerät %1.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="267"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Konnte keine EFI-Systempartition (ESP) auf irgendeinem Laufwerk finden. Bitte erstellen Sie eine ESP und versuchen Sie es erneut.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="294"/>
        <source>Success</source>
        <translation>Erfolg</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="295"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Prozess erfolgreich beendet. &lt;p&gt;&lt;b&gt;Wollen Sie MX Boot-Reparatur schliessen?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="301"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Prozess beendet. Es sind Fehler aufgetreten.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="303"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="387"/>
        <source>Select GRUB location</source>
        <translation>Auswahl des Ziels für GRUB</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="398"/>
        <source>Select Item to Back Up</source>
        <translation>Eintrag zur Sicherung auswählen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="405"/>
        <source>Select Item to Restore</source>
        <translation>Eintrag zum Wiederherstellen auswählen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="416"/>
        <source>Select backup file name</source>
        <translation>Wählen Sie den Backup-Dateinamen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>No file was selected.</source>
        <translation>Es wurde keine Datei ausgewählt.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="423"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Backup-Datei MBR oder PBR auswählen</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="444"/>
        <source>About MX Boot Repair</source>
        <translation>Über MX Boot-Reparatur</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>Version: </source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="447"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Einfaches Boot-Reparatur Program für MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="448"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="449"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="450"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="472"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
</context>
</TS>
